<?php

namespace Vidgyor\Category\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vidgyor\Category\Models\VideoCategory;

class VideoCategoryPolicy
{

    /**
     * Determine if the given user can view the video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, VideoCategory $video_category)
    {
        if ($user->canDo('category.video_category.view') && $user->isAdmin()) {
            return true;
        }

        return $video_category->user_id == user_id() && $video_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('category.video_category.create');
    }

    /**
     * Determine if the given user can update the given video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, VideoCategory $video_category)
    {
        if ($user->canDo('category.video_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $video_category->user_id == user_id() && $video_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VideoCategory $video_category)
    {
        return $video_category->user_id == user_id() && $video_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VideoCategory $video_category)
    {
        if ($user->canDo('category.video_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given video_category.
     *
     * @param UserPolicy $user
     * @param VideoCategory $video_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VideoCategory $video_category)
    {
        if ($user->canDo('category.video_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
